<img src='https://raw.githubusercontent.com/mtalyat/CHIVEL/refs/heads/main/Images/icon.png' width=200px>

# CHIVEL

CHIVEL, previously known as CHISL (Computer-Human Interaction Scripting Language) is a Python extension meant for controlling your device. It provides simple interfaces for finding things on the screen, controlling the keyboard/mouse, manipulating images, and more. This was originally its own scripting language, but was later revamped into a Python module, so that the powerful features of Python could be used in addition to the computer vision that CHIVEL provides. The project was also renamed from CHISL to CHIVEL, as CHISL was already taken on PyPI.

For more information, such as features, how-to's, and more, check out the [Github repository](https://github.com/mtalyat/CHIVEL).